﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.Windows;
using System.Windows.Input;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace GridTest2
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : INotifyPropertyChanged
	{
		public static MainWindow Instance { get; set; }

		public ICommand RemoveItemCommand { get; set; }

		public MainWindow()
		{
			InitializeComponent();
			DataContext = this;
			Instance = this;

			Items = new ObservableCollection<AddressBookRecord>();

			xamGrid.CellEnteredEditMode += (s, e) =>
			{
				Debug.WriteLine("Cell entered edit mode!");
				if (EditedRow == null)
					EditedRow = e.Cell.Row.Data as AddressBookRecord;
			};

			xamGrid.RowExitedEditMode += (s, e) =>
			{
				Debug.WriteLine("Row exited edit mode!");
				EditedRow = null;
				hideNewRow();
			};

			xamGrid.RowExitingEditMode += (s, e) =>
			{
				var data = e.Row.Data as AddressBookRecord;
				Debug.WriteLine(string.Format("Exiting: data is {0}", data.IsOkay() ? "valid" : "invalid"));

				if (!e.EditingCanceled && !data.IsOkay())
					e.Cancel = true;
			};
		}

		public ObservableCollection<AddressBookRecord> Items { get; set; }

		private AddressBookRecord _editedRow;
		public AddressBookRecord EditedRow
		{
			get { return _editedRow; }
			set { _editedRow = value; NotifyPropertyChanged("EditedRow"); }
		}

		public event PropertyChangedEventHandler PropertyChanged;
		public void NotifyPropertyChanged(string property)
		{
			var handler = PropertyChanged;
			if (handler != null) handler(this, new PropertyChangedEventArgs(property));
		}

		// ----------------------------------------------
		// Code-Behind part below
		// ----------------------------------------------

		private void addContactButton_Click(object sender, RoutedEventArgs e)
		{
			showNewRow();

			// Activate the Name editor in the Add New Item row
			var cellCtrl = Infragistics.Windows.Utilities.GetDescendantFromType(xamGrid, typeof(AddNewRowCellControl), true) as AddNewRowCellControl;
			xamGrid.EnterEditMode(cellCtrl.Cell.Row as Row);
		}

		private void showNewRow()
		{
			xamGrid.AddNewRowSettings.AllowAddNewRow = AddNewRowLocation.Top;
			xamGrid.UpdateLayout();	
		}

		private void hideNewRow()
		{
			// xamGrid.AddNewRowSettings.AllowAddNewRow = AddNewRowLocation.None;
		}
	}

	public class AddressBookRecord : INotifyPropertyChanged
	{
		private string _name;
		public string Name
		{
			get { return _name; }
			set
			{
				Debug.WriteLine(string.Format("Name setter! value = {0}", value));
				_name = value;
				NotifyPropertyChanged("Name");
			}
		}

		private string _email;
		public string Email
		{
			get { return _email; }
			set
			{
				Debug.WriteLine(string.Format("Email setter! value = {0}", value));
				_email = value;
				NotifyPropertyChanged("Email");
			}
		}

		public event PropertyChangedEventHandler PropertyChanged;
		protected void NotifyPropertyChanged(string property)
		{
			var handler = PropertyChanged;
			if (handler != null) handler(this, new PropertyChangedEventArgs(property));
		}
		
		public bool IsOkay()
		{
			return Email != null;
		}
	}
}
